@@ -71,6 +71,7 @@ use constant {
     CONNECT_ERROR       => 10,
     ENHANCE_YOUR_CALM   => 11,
     INADEQUATE_SECURITY => 12,
+    HTTP_1_1_REQUIRED   => 13,
 
     # SETTINGS
     SETTINGS_HEADER_TABLE_SIZE      => 1,
@@ -93,6 +94,7 @@ our %EXPORT_TAGS = (
         qw(NO_ERROR PROTOCOL_ERROR INTERNAL_ERROR FLOW_CONTROL_ERROR
           SETTINGS_TIMEOUT STREAM_CLOSED FRAME_SIZE_ERROR REFUSED_STREAM CANCEL
           COMPRESSION_ERROR CONNECT_ERROR ENHANCE_YOUR_CALM INADEQUATE_SECURITY
+          HTTP_1_1_REQUIRED
           )
     ],
     preface  => [qw(PREFACE)],
